==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescription } from "./WebGridActionButtonDescription";
/**
 * @hidden
 */
export let WebGridActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionButtonDescriptionMetadata.a == null) {
                WebGridActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionButtonDescriptionMetadata.c(WebGridActionButtonDescriptionMetadata.a);
            }
            if (a.j(WebGridActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionButton");
            a.item("__tagNameWC", "String:igc-grid-action-button");
            a.item("__packageNameWC", "String:grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("AsMenuItem", "Boolean");
            a.item("IconName", "String");
            a.item("ClassNames", "String");
            a.item("IconSet", "String");
            a.item("LabelText", "String");
        }
        static d(a) {
            WebGridActionButtonDescriptionMetadata.b(a);
            a.aa("WebGridActionButton", () => new WebGridActionButtonDescription());
            a.z("WebGridActionButton", WebGridActionButtonDescriptionMetadata.a);
        }
    }
    WebGridActionButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionButtonDescriptionMetadata, 'WebGridActionButtonDescriptionMetadata');
    WebGridActionButtonDescriptionMetadata.a = null;
    return WebGridActionButtonDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescription } from "./WebGridActionButtonDescription";
/**
 * @hidden
 */
export let WebGridActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionButtonDescriptionMetadata.a == null) {
                WebGridActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionButtonDescriptionMetadata.c(WebGridActionButtonDescriptionMetadata.a);
            }
            if (a.k(WebGridActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionButton");
            a.item("__tagNameWC", "String:igc-grid-action-button");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("AsMenuItem", "Boolean");
            a.item("IconName", "String");
            a.item("ClassNames", "String");
            a.item("IconSet", "String");
            a.item("LabelText", "String");
        }
        static d(a) {
            WebGridActionButtonDescriptionMetadata.b(a);
            a.ac("WebGridActionButton", () => new WebGridActionButtonDescription());
            a.ab("WebGridActionButton", WebGridActionButtonDescriptionMetadata.a);
        }
    }
    WebGridActionButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionButtonDescriptionMetadata, 'WebGridActionButtonDescriptionMetadata');
    WebGridActionButtonDescriptionMetadata.a = null;
    return WebGridActionButtonDescriptionMetadata;
})();
